@@ -4,7 +4,7 @@ from typing import Iterable, Optional, Tuple
 
 from attr import attrib, attrs
 
-__version__ = '0.24.0'
+__version__ = '0.25.0'
 
 
 Command = Tuple[str, ...]
@@ -40,6 +40,7 @@ class CommandTool:
 
 
 TOOLS = [
+    # Python source formatters
     CommandTool('flake8', default_files=()),
     CommandTool(
         'isort', run_params=('-c',), fix_params=(), default_files=('.',)
@@ -51,6 +52,13 @@ TOOLS = [
         fix_params=(),
         default_files=('.',),
     ),
+    # Markdown source formatters
+    CommandTool(
+        'mdformat',
+        run_params=('--check',),
+        fix_params=(),
+        default_files=('.',),
+    ),
 ]
 
 
